UssdHandlerPlatform class abstract
Abstract platform interface for the USSD handler plugin.
- Inheritance
-
- Object
- PlatformInterface
- UssdHandlerPlatform
- Implementers
Constructors
- UssdHandlerPlatform()
- Constructs a UssdHandlerPlatform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
cancelMultiSession(
) → Future< Map< String, dynamic> > - Cancels the active multi-session USSD session
-
checkPhonePermissions(
) → Future< bool> - Check if the package has the CALL_PHONE and READ_PHONE_STATE permissions.
-
executeUssd(
String ussdCode, {int? subscriptionId}) → Future< UssdResponse> - Executes a USSD code
-
executeUssdDirect(
String ussdCode, int timeoutSeconds, {int? subscriptionId, bool iosFallbackToStandard = false}) → Future< String?> - Executes a USSD code directly and gets the response without showing the native system dialog (Android only)
-
getPlatformVersion(
) → Future< String?> - Returns the OS version string, e.g., "Android 13" or "iOS 17.0".
-
getSystemInfo(
) → Future< Map< String, dynamic> ?> - Gets system information and device capabilities for diagnostics.
-
hasUssdDirectPermissions(
) → Future< bool> - Checks if it has the necessary permissions for direct USSD
-
isAccessibilityServiceEnabled(
) → Future< bool> - Checks if the accessibility service is enabled
-
isMultiSessionActive(
) → Future< bool> - Checks if there is an active multi-session USSD session
-
isPermissionPermanentlyDenied(
) → Future< bool> -
Returns
trueif the user checked the "Don't ask again" option. Always returnsfalseon iOS. -
isUssdSupported(
) → Future< bool> - Checks if the device supports USSD codes
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
openAccessibilitySettings(
) → Future< bool> - Opens the accessibility services settings
-
openAppSettings(
) → Future< bool> - Opens the application settings screen in the operating system.
-
requestPhonePermissions(
) → Future< bool> - Requests the necessary permissions natively, without third-party dependencies.
-
sendMessageInSession(
String message) → Future< Map< String, dynamic> > - Sends a message in the active multi-session USSD session
-
setupAccessibilityEventChannel(
) → Future< Map< String, dynamic> > - Configures the event channel for the accessibility service
-
shouldShowPermissionRationale(
) → Future< bool> - Indicates whether an explanation should be shown to the user (Temporarily denied)
-
startMultiSessionUssd(
String ussdCode, {int? subscriptionId}) → Future< Map< String, dynamic> > - Starts a multi-session USSD session
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ UssdHandlerPlatform
-
The default instance of UssdHandlerPlatform to use.
getter/setter pair