- Inheritance
-
- Object
- PlatformInterface
- UssdHandlerPlatform
- Implementers
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
cancelMultiSession()
→ Future<Map<String, dynamic>>
-
Cancels the active multi-session USSD session
-
checkPhonePermissions()
→ Future<bool>
-
Check if the package has the CALL_PHONE and READ_PHONE_STATE permissions.
-
executeUssd(String ussdCode, {int? subscriptionId})
→ Future<UssdResponse>
-
Executes a USSD code
-
executeUssdDirect(String ussdCode, int timeoutSeconds, {int? subscriptionId, bool iosFallbackToStandard = false})
→ Future<String?>
-
Executes a USSD code directly and gets the response
without showing the native system dialog (Android only)
-
getPlatformVersion()
→ Future<String?>
-
-
getSystemInfo()
→ Future<Map<String, dynamic>?>
-
Gets system information for diagnostics (Android only)
-
hasUssdDirectPermissions()
→ Future<bool>
-
Checks if it has the necessary permissions for direct USSD
-
isAccessibilityServiceEnabled()
→ Future<bool>
-
Checks if the accessibility service is enabled
-
isMultiSessionActive()
→ Future<bool>
-
Checks if there is an active multi-session USSD session
-
isPermissionPermanentlyDenied()
→ Future<bool>
-
Returns
true if the user checked the "Don't ask again" option.
Always returns false on iOS.
-
isUssdSupported()
→ Future<bool>
-
Checks if the device supports USSD codes
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
openAccessibilitySettings()
→ Future<bool>
-
Opens the accessibility services settings
-
openAppSettings()
→ Future<bool>
-
Opens the application settings screen in the operating system.
-
requestPhonePermissions()
→ Future<bool>
-
Requests the necessary permissions natively, without third-party dependencies.
-
sendMessageInSession(String message)
→ Future<Map<String, dynamic>>
-
Sends a message in the active multi-session USSD session
-
setupAccessibilityEventChannel()
→ Future<Map<String, dynamic>>
-
Configures the event channel for the accessibility service
-
shouldShowPermissionRationale()
→ Future<bool>
-
Indicates whether an explanation should be shown to the user (Temporarily denied)
-
startMultiSessionUssd(String ussdCode, {int? subscriptionId})
→ Future<Map<String, dynamic>>
-
Starts a multi-session USSD session
-
toString()
→ String
-
A string representation of this object.
inherited